#include "orbsvcs/IFRService/IDLType_i.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_IDLType_i::TAO_IDLType_i (TAO_Repository_i *repo)
  : TAO_IRObject_i (repo)
{
}

TAO_IDLType_i::~TAO_IDLType_i ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
